@@ -95,7 +95,7 @@ def init(
 
             spec = importlib.util.find_spec("specfact_cli")
             if spec and spec.origin:
-                package_dir = Path(spec.origin).parent.parent
+                package_dir = Path(spec.origin) #.parent.parent
                 templates_dir = package_dir / "resources" / "prompts"
                 if not templates_dir.exists():
                     # Fallback: try resources/prompts in project root
