@@ -94,7 +94,9 @@ def _perform_sync_operation(
 
         if is_constitution_minimal(constitution_path):
             # Auto-generate in test mode, prompt in interactive mode
-            if os.environ.get("TEST_MODE") == "true":
+            # Check for test environment (TEST_MODE or PYTEST_CURRENT_TEST)
+            is_test_env = os.environ.get("TEST_MODE") == "true" or os.environ.get("PYTEST_CURRENT_TEST") is not None
+            if is_test_env:
                 # Auto-generate bootstrap constitution in test mode
                 from specfact_cli.enrichers.constitution_enricher import ConstitutionEnricher
 
@@ -102,22 +104,33 @@ def _perform_sync_operation(
                 enriched_content = enricher.bootstrap(repo, constitution_path)
                 constitution_path.write_text(enriched_content, encoding="utf-8")
             else:
-                console.print("[yellow]⚠[/yellow] Constitution is minimal (essentially empty)")
-                suggest_bootstrap = typer.confirm(
-                    "Generate bootstrap constitution from repository analysis?",
-                    default=True,
-                )
-                if suggest_bootstrap:
-                    from specfact_cli.enrichers.constitution_enricher import ConstitutionEnricher
+                # Check if we're in an interactive environment
+                import sys
 
-                    console.print("[dim]Generating bootstrap constitution...[/dim]")
-                    enricher = ConstitutionEnricher()
-                    enriched_content = enricher.bootstrap(repo, constitution_path)
-                    constitution_path.write_text(enriched_content, encoding="utf-8")
-                    console.print("[bold green]✓[/bold green] Bootstrap constitution generated")
-                    console.print("[dim]Review and adjust as needed before syncing[/dim]")
+                is_interactive = (hasattr(sys.stdin, "isatty") and sys.stdin.isatty()) and sys.stdin.isatty()
+                if is_interactive:
+                    console.print("[yellow]⚠[/yellow] Constitution is minimal (essentially empty)")
+                    suggest_bootstrap = typer.confirm(
+                        "Generate bootstrap constitution from repository analysis?",
+                        default=True,
+                    )
+                    if suggest_bootstrap:
+                        from specfact_cli.enrichers.constitution_enricher import ConstitutionEnricher
+
+                        console.print("[dim]Generating bootstrap constitution...[/dim]")
+                        enricher = ConstitutionEnricher()
+                        enriched_content = enricher.bootstrap(repo, constitution_path)
+                        constitution_path.write_text(enriched_content, encoding="utf-8")
+                        console.print("[bold green]✓[/bold green] Bootstrap constitution generated")
+                        console.print("[dim]Review and adjust as needed before syncing[/dim]")
+                    else:
+                        console.print(
+                            "[dim]Skipping bootstrap. Run 'specfact constitution bootstrap' manually if needed[/dim]"
+                        )
                 else:
-                    console.print("[dim]Skipping bootstrap. Run 'specfact constitution bootstrap' manually if needed[/dim]")
+                    # Non-interactive mode: skip prompt
+                    console.print("[yellow]⚠[/yellow] Constitution is minimal (essentially empty)")
+                    console.print("[dim]Run 'specfact constitution bootstrap --repo .' to generate constitution[/dim]")
 
     console.print("[bold green]✓[/bold green] Constitution found and validated")
 
