@@ -7,6 +7,7 @@ to SpecFact format (plans, protocols).
 
 from __future__ import annotations
 
+import re
 from pathlib import Path
 from typing import Any
 
@@ -260,6 +261,16 @@ class SpecKitConverter:
                         if (story_ref and story_ref in story_key) or not story_ref:
                             tasks.append(task.get("description", ""))
 
+            # Extract scenarios from Spec-Kit format (Primary, Alternate, Exception, Recovery)
+            scenarios = story_data.get("scenarios")
+            # Ensure scenarios dict has correct format (filter out empty lists)
+            if scenarios and isinstance(scenarios, dict):
+                # Filter out empty scenario lists
+                filtered_scenarios = {k: v for k, v in scenarios.items() if v and isinstance(v, list) and len(v) > 0}
+                scenarios = filtered_scenarios if filtered_scenarios else None
+            else:
+                scenarios = None
+
             story = Story(
                 key=story_key,
                 title=story_title,
@@ -270,6 +281,8 @@ class SpecKitConverter:
                 tasks=tasks,
                 confidence=0.8,  # High confidence from spec
                 draft=False,
+                scenarios=scenarios,
+                contracts=None,
             )
             stories.append(story)
 
@@ -372,9 +385,13 @@ class SpecKitConverter:
         """
         features_converted = 0
 
-        for feature in plan_bundle.features:
+        for idx, feature in enumerate(plan_bundle.features, start=1):
             # Generate feature directory name from key (FEATURE-001 -> 001-feature-name)
+            # Use number from key if available, otherwise use sequential index
             feature_num = self._extract_feature_number(feature.key)
+            if feature_num == 0:
+                # No number found in key, use sequential numbering (1, 2, 3, ...)
+                feature_num = idx
             feature_name = self._to_feature_dir_name(feature.title)
 
             # Create feature directory
@@ -472,10 +489,20 @@ class SpecKitConverter:
                 for acc_idx, acc in enumerate(story.acceptance, start=1):
                     # Parse Given/When/Then if available
                     if "Given" in acc and "When" in acc and "Then" in acc:
-                        parts = acc.split(", ")
-                        given = parts[0].replace("Given ", "").strip()
-                        when = parts[1].replace("When ", "").strip()
-                        then = parts[2].replace("Then ", "").strip()
+                        # Use regex to properly extract Given/When/Then parts
+                        # This handles commas inside type hints (e.g., "dict[str, Any]")
+                        gwt_pattern = r"Given\s+(.+?),\s*When\s+(.+?),\s*Then\s+(.+?)(?:$|,)"
+                        match = re.search(gwt_pattern, acc, re.IGNORECASE | re.DOTALL)
+                        if match:
+                            given = match.group(1).strip()
+                            when = match.group(2).strip()
+                            then = match.group(3).strip()
+                        else:
+                            # Fallback to simple split if regex fails
+                            parts = acc.split(", ")
+                            given = parts[0].replace("Given ", "").strip() if len(parts) > 0 else ""
+                            when = parts[1].replace("When ", "").strip() if len(parts) > 1 else ""
+                            then = parts[2].replace("Then ", "").strip() if len(parts) > 2 else ""
                         lines.append(f"{acc_idx}. **Given** {given}, **When** {when}, **Then** {then}")
 
                         # Categorize scenarios based on keywords
@@ -621,7 +648,10 @@ class SpecKitConverter:
         return "\n".join(lines)
 
     @beartype
-    @require(lambda feature, plan_bundle: isinstance(feature, Feature) and isinstance(plan_bundle, PlanBundle), "Must be Feature and PlanBundle instances")
+    @require(
+        lambda feature, plan_bundle: isinstance(feature, Feature) and isinstance(plan_bundle, PlanBundle),
+        "Must be Feature and PlanBundle instances",
+    )
     @ensure(lambda result: isinstance(result, str), "Must return string")
     def _generate_plan_markdown(self, feature: Feature, plan_bundle: PlanBundle) -> str:
         """Generate Spec-Kit plan.md content from SpecFact feature."""
@@ -703,9 +733,66 @@ class SpecKitConverter:
         lines.append("- [ ] Single model representation?")
         lines.append("")
         lines.append("**Article IX (Integration-First)**:")
-        lines.append("- [ ] Contracts defined?")
-        lines.append("- [ ] Contract tests written?")
+        # Check if contracts are defined in stories
+        contracts_defined = any(story.contracts for story in feature.stories if story.contracts)
+        if contracts_defined:
+            lines.append("- [x] Contracts defined?")
+            lines.append("- [ ] Contract tests written?")
+        else:
+            lines.append("- [ ] Contracts defined?")
+            lines.append("- [ ] Contract tests written?")
         lines.append("")
+
+        # Add contract definitions section if contracts exist (Step 2.1)
+        if contracts_defined:
+            lines.append("### Contract Definitions")
+            lines.append("")
+            for story in feature.stories:
+                if story.contracts:
+                    lines.append(f"#### {story.title}")
+                    lines.append("")
+                    contracts = story.contracts
+
+                    # Parameters
+                    if contracts.get("parameters"):
+                        lines.append("**Parameters:**")
+                        for param in contracts["parameters"]:
+                            param_type = param.get("type", "Any")
+                            required = "required" if param.get("required", True) else "optional"
+                            default = f" (default: {param.get('default')})" if param.get("default") is not None else ""
+                            lines.append(f"- `{param['name']}`: {param_type} ({required}){default}")
+                        lines.append("")
+
+                    # Return type
+                    if contracts.get("return_type"):
+                        return_type = contracts["return_type"].get("type", "Any")
+                        lines.append(f"**Return Type**: `{return_type}`")
+                        lines.append("")
+
+                    # Preconditions
+                    if contracts.get("preconditions"):
+                        lines.append("**Preconditions:**")
+                        for precondition in contracts["preconditions"]:
+                            lines.append(f"- {precondition}")
+                        lines.append("")
+
+                    # Postconditions
+                    if contracts.get("postconditions"):
+                        lines.append("**Postconditions:**")
+                        for postcondition in contracts["postconditions"]:
+                            lines.append(f"- {postcondition}")
+                        lines.append("")
+
+                    # Error contracts
+                    if contracts.get("error_contracts"):
+                        lines.append("**Error Contracts:**")
+                        for error_contract in contracts["error_contracts"]:
+                            exc_type = error_contract.get("exception_type", "Exception")
+                            condition = error_contract.get("condition", "Error condition")
+                            lines.append(f"- `{exc_type}`: {condition}")
+                        lines.append("")
+            lines.append("")
+
         # Status should be PENDING until gates are actually checked
         # Users should review and check gates based on their project's actual state
         lines.append("**Status**: PENDING")
